pub struct RateLimitWindow { /* private fields */ }Expand description
Rate limit window manager Handles periodic reset of rate limit counters for time window management
Implementations
Sourceimpl RateLimitWindow
impl RateLimitWindow
pub fn new(sync_manager: Arc<MeshSyncManager>, window_seconds: u64) -> Self
Sourcepub async fn start_reset_task(self, shutdown_rx: Receiver<bool>)
pub async fn start_reset_task(self, shutdown_rx: Receiver<bool>)
Start the window reset task This task periodically resets the global rate limit counter
Arguments
shutdown_rx- A watch receiver that signals when to stop the task